@@ -544,10 +544,11 @@ ax_slowkeys_warning_post_bubble (GsdA11yKeyboardManager *manager,
         }
 
         gsd_a11y_keyboard_manager_ensure_status_icon (manager);
-        manager->priv->notification = notify_notification_new_with_status_icon (title,
-                                                                                message,
-                                                                                "preferences-desktop-accessibility",
-                                                                                manager->priv->status_icon);
+        manager->priv->notification = notify_notification_new (title,
+                                                               message,
+                                                               "preferences-desktop-accessibility",
+                                                               NULL);
+        notify_notification_attach_to_status_icon (manager->priv->notification, manager->priv->status_icon);
         notify_notification_set_timeout (manager->priv->notification, NOTIFICATION_TIMEOUT * 1000);
 
         notify_notification_add_action (manager->priv->notification,
@@ -626,7 +627,7 @@ ax_slowkeys_warning_post_dialog (GsdA11yKeyboardManager *manager,
         gtk_window_set_title (GTK_WINDOW (manager->priv->slowkeys_alert),
                               _("Slow Keys Alert"));
         gtk_window_set_icon_name (GTK_WINDOW (manager->priv->slowkeys_alert),
-                                  "gnome-dev-keyboard");
+                                  "input-keyboard");
         gtk_dialog_set_default_response (GTK_DIALOG (manager->priv->slowkeys_alert),
                                          GTK_RESPONSE_ACCEPT);
 
@@ -688,10 +689,11 @@ ax_stickykeys_warning_post_bubble (GsdA11yKeyboardManager *manager,
         }
 
         gsd_a11y_keyboard_manager_ensure_status_icon (manager);
-        manager->priv->notification = notify_notification_new_with_status_icon (title,
-                                                                                message,
-                                                                                "preferences-desktop-accessibility",
-                                                                                manager->priv->status_icon);
+        manager->priv->notification = notify_notification_new (title,
+                                                               message,
+                                                               "preferences-desktop-accessibility",
+                                                               NULL);
+        notify_notification_attach_to_status_icon (manager->priv->notification, manager->priv->status_icon);
         notify_notification_set_timeout (manager->priv->notification, NOTIFICATION_TIMEOUT * 1000);
 
         notify_notification_add_action (manager->priv->notification,
@@ -772,7 +774,7 @@ ax_stickykeys_warning_post_dialog (GsdA11yKeyboardManager *manager,
         gtk_window_set_title (GTK_WINDOW (manager->priv->stickykeys_alert),
                               _("Sticky Keys Alert"));
         gtk_window_set_icon_name (GTK_WINDOW (manager->priv->stickykeys_alert),
-                                  "gnome-dev-keyboard");
+                                  "input-keyboard");
         gtk_dialog_set_default_response (GTK_DIALOG (manager->priv->stickykeys_alert),
                                          GTK_RESPONSE_ACCEPT);
 
